"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
function fixControlledValue(value) {
    if (typeof value === 'undefined' || value === null) {
        return '';
    }
    return value;
}
/**
 * 百度UEditor的React封装
 */
var UEditor = /** @class */ (function (_super) {
    __extends(UEditor, _super);
    function UEditor(props) {
        var _this = _super.call(this, props) || this;
        _this.state = {
            ueditorEventRegistered: false,
        };
        _this._getUEditorAsync = _this._getUEditorAsync.bind(_this);
        _this._getUEditorSync = _this._getUEditorSync.bind(_this);
        _this._initUEditor = _this._initUEditor.bind(_this);
        _this._waitUntilUEditorloaded = _this._waitUntilUEditorloaded.bind(_this);
        return _this;
    }
    UEditor.prototype._getUEditorAsync = function () {
        var _this = this;
        var _a = this.props, id = _a.id, width = _a.width, height = _a.height;
        return new Promise(function (resolve, reject) {
            var ue = UE.getEditor(id, {
                initialFrameWidth: width,
                initialFrameHeight: height,
            });
            resolve(ue);
        }).catch(function (e) {
            console.log("ue not yet ready...");
            return _this._timeoutPromise(30)
                .then(_this._getUEditorAsync());
        });
    };
    UEditor.prototype._getUEditorSync = function () {
        var _a = this.props, id = _a.id, width = _a.width, height = _a.height;
        var ue = UE.getEditor(id, {
            initialFrameWidth: width,
            initialFrameHeight: height,
        });
        return ue;
    };
    UEditor.prototype._initUEditor = function () {
        var _this = this;
        var ue = this._getUEditorSync();
        if (this.state.ueditorEventRegistered) {
            return Promise.resolve(ue);
        }
        else {
            var onChange_1 = this.props.onChange;
            return new Promise(function (resolve, reject) {
                ue.addListener('beforeSetContent', function () {
                    window.SIMEPLE_REACT_UI_UEDITOR_FOCUS_ELEMENT = document.activeElement;
                    console.log('before', window.SIMEPLE_REACT_UI_UEDITOR_FOCUS_ELEMENT);
                });
                ue.addListener('contentChange', function (type) {
                    var content = ue.getContent();
                    // 触发 onChange()  回调
                    onChange_1(content);
                    var element = window.SIMEPLE_REACT_UI_UEDITOR_FOCUS_ELEMENT;
                    if (element && element.focus) {
                        element.focus();
                    }
                    console.log('onchagne ', element);
                });
                ue.addListener('afterSetContent', function () {
                    var element = window.SIMEPLE_REACT_UI_UEDITOR_FOCUS_ELEMENT;
                    if (element && element.focus) {
                        element.focus();
                    }
                    console.log('after', element);
                });
                _this.setState({ ueditorEventRegistered: true }, function () {
                    resolve(ue);
                });
            });
        }
    };
    UEditor.prototype._timeoutPromise = function (timeout) {
        return new Promise(function (resolve, reject) {
            setTimeout(resolve, timeout);
        });
    };
    UEditor.prototype._waitUntilUEditorloaded = function () {
        var _initUEditor = this._initUEditor;
        var _a = this.props, id = _a.id, width = _a.width, height = _a.height, onChange = _a.onChange;
        var timeoutPromise = this._timeoutPromise;
        function waitUntil() {
            return new Promise(function (resolve, reject) {
                var ue = UE.getEditor(id, {
                    initialFrameWidth: width,
                    initialFrameHeight: height,
                });
                ue.setDisabled();
                ue.ready(function () {
                    ue.setEnabled();
                    ue.blur();
                    _initUEditor().then(function (ue) { return resolve(ue); });
                });
            }).catch(function (err) {
                console.log("the UE has not been ready yet. waitting 30ms ...", err);
                return timeoutPromise(30).then(function () {
                    return waitUntil();
                });
            });
        }
        return waitUntil();
    };
    /**
     *
     * @param nextProps
     */
    UEditor.prototype.componentWillReceiveProps = function (nextProps) {
        var _this = this;
        return this._getUEditorAsync()
            .then(function (ue) {
            // 只有在受控模式下，才会试图同步编辑器的值
            if ('value' in nextProps) {
                var nextValue = fixControlledValue(nextProps.value);
                var thisValue = fixControlledValue(_this.props.value);
                // 如果下一个value值和现在的value值相同，则不再同步。
                if (nextValue !== thisValue) {
                    ue.setContent(nextValue, false, true); // 不追加，不触发选区变化
                    return;
                }
            }
        });
    };
    UEditor.prototype.componentWillMount = function () {
        var scriptConfig = document.querySelector("script[src='" + this.props.uconfigSrc + "']");
        if (!scriptConfig) {
            scriptConfig = document.createElement("script");
            scriptConfig.src = this.props.uconfigSrc;
            document.body.appendChild(scriptConfig);
        }
        var scriptEditor = document.querySelector("script[src='" + this.props.ueditorSrc + "']");
        if (!scriptEditor) {
            scriptEditor = document.createElement("script");
            scriptEditor.src = this.props.ueditorSrc;
            document.body.appendChild(scriptEditor);
        }
    };
    UEditor.prototype.componentDidMount = function () {
        var _a = this.props, id = _a.id, width = _a.width, height = _a.height, initialContent = _a.initialContent, value = _a.value, afterInit = _a.afterInit, onChange = _a.onChange;
        if ('value' in this.props) {
            value = fixControlledValue(value);
            initialContent = value;
        }
        else {
            initialContent = fixControlledValue(initialContent);
        }
        return this._waitUntilUEditorloaded()
            .then(function (ue) {
            var element = document.activeElement;
            ue.setContent(initialContent);
            element.focus();
            // 触发 afterInit() 回调
            afterInit(ue);
        });
    };
    UEditor.prototype.componentWillUnmount = function () {
        UE.delEditor(this.props.id);
        // 不再卸载<script> :
        //     <script type="text/javascript" src="/static/ueditor/ueditor.config.js"></script>
        //     <script type="text/javascript" src="/static/ueditor/ueditor.all.min.js"></script>
    };
    UEditor.prototype.render = function () {
        return (React.createElement("script", { id: this.props.id, type: "text/plain" }));
    };
    UEditor.defaultProps = {
        id: 'ueditorcontainer',
        height: 600,
        width: 600,
        uconfigSrc: "/static/ueditor/ueditor.config.js",
        ueditorSrc: "/static/ueditor/ueditor.all.min.js",
        afterInit: function (ue) { },
        onChange: function (content) { },
    };
    return UEditor;
}(React.Component));
exports.UEditor = UEditor;
exports.default = UEditor;
//# sourceMappingURL=index.js.map